@@ -1,9 +1,27 @@
-// (c) 2000 Peter Putzer <putzer@kde.org>
+/*
+   Copyright 2000 Peter Putzer <putzer@kde.org>
+
+   This program is free software; you can redistribute it and/or
+   modify it under the terms of the GNU General Public
+   License as published by the Free Software Foundation; either
+   version 2 of the License, or (at your option) any later version.
+
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+*/
 
 #include <qtimer.h>
 #include <qfileinfo.h>
-#include <qlayout.h>
-#include <qtooltip.h>
+#include <QLayout>
+
+//Added by qt3to4:
+#include <Q3Frame>
 
 #include <kdebug.h>
 #include <kiconloader.h>
@@ -12,11 +30,11 @@
 
 #include "ksv_core.h"
 #include "RunlevelAuthIcon.h"
-#include <qlabel.h>
+#include <QLabel>
 
 RunlevelAuthIcon::RunlevelAuthIcon (const QString& servicesPath, const QString& runlevelPath,
 									QWidget* parent, const char* name)
-  : KAuthIcon (parent, name),
+  : KAuthIcon (parent),
 	mTimer (new QTimer (this)),
 	mServicesInfo (new QFileInfo (servicesPath)),
     mRLInfo (new QFileInfo* [ksv::runlevelNumber]),
@@ -36,7 +54,7 @@ RunlevelAuthIcon::RunlevelAuthIcon (const QString& servicesPath, const QString&
   lockBox->setPixmap (lockPM);
 
   lockBox->setMargin (1);
-  lockBox->setFrameStyle (QFrame::NoFrame);
+  lockBox->setFrameStyle (Q3Frame::NoFrame);
   lockBox->setFixedSize (lockBox->sizeHint());
 
   connect (mTimer, SIGNAL (timeout()), this, SLOT (timerEvent()));
@@ -75,8 +93,7 @@ void RunlevelAuthIcon::updateStatus ()
 	  lockBox->setPixmap (res ? openLockPM : lockPM);
 	  lockLabel->setText (res ? openLockText : lockText);
 
-	  QToolTip::remove (this);
-	  QToolTip::add (this, lockLabel->text());
+	  this->setToolTip( lockLabel->text());
 
       mOld = res;
 	  emit authChanged (res);
@@ -138,7 +155,7 @@ void RunlevelAuthIcon::setRefreshInterval (int interval)
 
 void RunlevelAuthIcon::setCheckEnabled (bool on)
 {
-  kdDebug(3000) << "enabling authicon " << on << endl;
+  kDebug(3000) << "enabling authicon " << on;
   mCheckEnabled = on;
 
   // refresh everything
